@@ -20,8 +20,8 @@
  * probably need to modify both.
  *
  * Written by Roland Schemers
- * Copyright 2002, 2003, 2006, 2007, 2009, 2010
- *     Board of Trustees, Leland Stanford Jr. University
+ * Copyright 2002, 2003, 2006, 2007, 2009, 2010, 2011
+ *     The Board of Trustees of the Leland Stanford Junior University
  *
  * See LICENSE for licensing terms.
  */
@@ -133,7 +133,6 @@ open_keytab(WEBAUTH_KRB5_CTXTP *c, const char *keytab_path,
     krb5_keytab id;
     krb5_kt_cursor cursor;
     krb5_keytab_entry entry;
-    krb5_error_code tcode;
 
     assert(c != NULL);
     assert(keytab_path != NULL);
@@ -151,7 +150,7 @@ open_keytab(WEBAUTH_KRB5_CTXTP *c, const char *keytab_path,
         c->code = krb5_kt_start_seq_get(c->ctx, id, &cursor);
         if (c->code != 0) {
             /* FIXME: needs better logging. */
-            tcode = krb5_kt_close(c->ctx, id);
+            krb5_kt_close(c->ctx, id);
             return WA_ERR_KRB5;
         }
 
@@ -159,14 +158,11 @@ open_keytab(WEBAUTH_KRB5_CTXTP *c, const char *keytab_path,
         if (c->code == 0) {
             c->code = krb5_copy_principal(c->ctx, entry.principal,
                                           out_principal);
-            /*
-             * Use tcode from this point on so that we don't lose value of
-             * c->code.  FIXME: needs better logging.
-             */
-            tcode = krb5_kt_free_entry(c->ctx, &entry);
+            /* FIXME: needs better logging. */
+            krb5_kt_free_entry(c->ctx, &entry);
         }
         /* FIXME: needs better logging. */
-        tcode = krb5_kt_end_seq_get(c->ctx, id, &cursor);
+        krb5_kt_end_seq_get(c->ctx, id, &cursor);
     }
 
     if (c->code == 0) {
@@ -174,7 +170,7 @@ open_keytab(WEBAUTH_KRB5_CTXTP *c, const char *keytab_path,
         return WA_ERR_NONE;
     } else {
         *id_out = NULL;
-        tcode = krb5_kt_close(c->ctx, id);
+        krb5_kt_close(c->ctx, id);
         return WA_ERR_KRB5;
     }
 }
@@ -405,20 +401,51 @@ webauth_krb5_change_password(WEBAUTH_KRB5_CTXT *context,
     int retval;
     krb5_data result_code_string, result_string;
     char *username = NULL;
+#if HAVE_KRB5_MIT
+    krb5_creds in, *out = NULL;
+#endif
 
     assert(c != NULL);
     assert(password != NULL);
 
     memset(&result_code_string, 0, sizeof(krb5_data));
     memset(&result_string, 0, sizeof(krb5_data));
+    if (c->pwchange_err != NULL) {
+        free(c->pwchange_err);
+        c->pwchange_err = NULL;
+    }
 
     krb5_unparse_name(c->ctx, c->princ, &username);
 
-    /* The actual change. */
+    /*
+     * The actual change.  MIT Kerberos up to at least 1.9 has a bug in the
+     * set_password implementation that causes it to misparse replies that are
+     * larger than 256 bytes and return an incorrect error code, so for MIT
+     * Kerberos we use the old change_password API instead.
+     */
+#if HAVE_KRB5_MIT
+    memset(&in, 0, sizeof(in));
+    c->code = krb5_copy_principal(c->ctx, c->princ, &in.client);
+    if (c->code != 0)
+        goto done;
+    c->code = krb5_build_principal(c->ctx, &in.server,
+                                   krb5_princ_realm(c->ctx, c->princ)->length,
+                                   krb5_princ_realm(c->ctx, c->princ)->data,
+                                   "kadmin", "changepw", NULL);
+    if (c->code != 0)
+        goto done;
+    c->code = krb5_get_credentials(c->ctx, 0, c->cc, &in, &out);
+    if (c->code != 0)
+        goto done;
+    c->code = krb5_change_password(c->ctx, out, (char *) password,
+                                   &result_code, &result_code_string,
+                                   &result_string);
+#else
     c->code = krb5_set_password_using_ccache(c->ctx, c->cc, (char *) password,
                                              c->princ, &result_code,
                                              &result_code_string,
                                              &result_string);
+#endif /* !HAVE_KRB5_MIT */
 
     /* Everything from here on is just handling diagnostics and output. */
     if (c->code != 0)
@@ -443,6 +470,11 @@ done:
     krb5_free_data_contents(c->ctx, &result_code_string);
     if (username != NULL)
         krb5_free_unparsed_name(c->ctx, username);
+#if HAVE_KRB5_MIT
+    krb5_free_cred_contents(c->ctx, &in);
+    if (out != NULL)
+        krb5_free_creds(c->ctx, out);
+#endif
     return (c->code == 0) ? WA_ERR_NONE : WA_ERR_KRB5;
 }
 
@@ -609,6 +641,8 @@ webauth_krb5_free(WEBAUTH_KRB5_CTXT *context)
         krb5_free_principal(c->ctx, c->princ);
     if (c->ctx != NULL)
         krb5_free_context(c->ctx);
+    if (c->pwchange_err != NULL)
+        free(c->pwchange_err);
     free(context);
     return WA_ERR_NONE;
 }
@@ -662,7 +696,6 @@ webauth_krb5_init_via_keytab(WEBAUTH_KRB5_CTXT *context,
     krb5_creds creds;
     krb5_get_init_creds_opt *opts;
     krb5_keytab keytab;
-    krb5_error_code tcode;
     int s;
 
     assert(c != NULL);
@@ -682,19 +715,19 @@ webauth_krb5_init_via_keytab(WEBAUTH_KRB5_CTXT *context,
 
     c->code = krb5_cc_resolve(c->ctx, cache_name, &c->cc);
     if (c->code != 0) {
-        tcode = krb5_kt_close(c->ctx, keytab);
+        krb5_kt_close(c->ctx, keytab);
         return WA_ERR_KRB5;
     }
 
     c->code = krb5_cc_initialize(c->ctx, c->cc, c->princ);
     if (c->code != 0) {
-        tcode = krb5_kt_close(c->ctx, keytab);
+        krb5_kt_close(c->ctx, keytab);
         return WA_ERR_KRB5;
     }
 
     c->code = krb5_get_init_creds_opt_alloc(c->ctx, &opts);
     if (c->code != 0) {
-        tcode = krb5_kt_close(c->ctx, keytab);
+        krb5_kt_close(c->ctx, keytab);
         return WA_ERR_KRB5;
     }
     krb5_get_init_creds_opt_set_default_flags(c->ctx, "webauth", NULL, opts);
@@ -704,7 +737,7 @@ webauth_krb5_init_via_keytab(WEBAUTH_KRB5_CTXT *context,
     krb5_get_init_creds_opt_free(c->ctx, opts);
 
     /* FIXME: needs better logging. */
-    tcode = krb5_kt_close(c->ctx, keytab);
+    krb5_kt_close(c->ctx, keytab);
 
     if (c->code != 0) {
         switch (c->code) {
