@@ -6,7 +6,7 @@
 #
 # Written by Roland Schemers
 # Copyright 2003, 2005, 2008, 2009
-#     Board of Trustees, Leland Stanford Jr. University
+#     The Board of Trustees of the Leland Stanford Junior University
 #
 # See LICENSE for licensing terms.
 
@@ -442,7 +442,7 @@ in order to then later use that to change the user password.
 
 If $keytab is not defined, then we do not obtain a TGT, but only initialize
 the context without verifying its validity.  This is currently only used in
-conjuction with $get_principal to get credentials for kadmin/changepw.
+conjunction with $get_principal to get credentials for kadmin/changepw.
 
 Returns the server principal used to verify the TGT.
 
